==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5flongbranch.h <==
// class soot.coffi.Instruction_longbranch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 5e7f431907ff88dc soot_coffi_Instruction__5flongbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbranch

#include "soot/coffi/Instruction__5fbranch.h"

#ifndef _JC_soot_coffi_Instruction__5flongbranch_H_
#define _JC_soot_coffi_Instruction__5flongbranch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5flongbranch$sub_refs	_jc_soot_coffi_Instruction__5flongbranch$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs	_jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$refs	_jc_soot_coffi_Instruction__5flongbranch$refs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$nonrefs	_jc_soot_coffi_Instruction__5flongbranch$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$object	_jc_soot_coffi_Instruction__5flongbranch$object;

typedef const struct _jc_soot_coffi_Instruction__5flongbranch$vmethods	_jc_soot_coffi_Instruction__5flongbranch$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5flongbranch$vtable	_jc_soot_coffi_Instruction__5flongbranch$vtable;
typedef const struct _jc_soot_coffi_Instruction__5flongbranch$vtype	_jc_soot_coffi_Instruction__5flongbranch$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5flongbranch$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, jbyte);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5flongbranch$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint);
extern jint _jc_soot_coffi_Instruction__5flongbranch$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, jint);
extern jint _jc_soot_coffi_Instruction__5flongbranch$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5flongbranch$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5flongbranch$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5flongbranch$method_info$parse$107dd9a35b0eb485;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5flongbranch$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint);
};

// Vtable
struct _jc_soot_coffi_Instruction__5flongbranch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5flongbranch$vmethods	soot_coffi_Instruction__5flongbranch;
};

// Vtype
struct _jc_soot_coffi_Instruction__5flongbranch$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5flongbranch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5flongbranch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5flongbranch$refs {
    _jc_soot_coffi_Instruction__5flongbranch$sub_refs	soot_coffi_Instruction__5flongbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5flongbranch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs	soot_coffi_Instruction__5flongbranch;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5flongbranch$object {
	_jc_soot_coffi_Instruction__5flongbranch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5flongbranch$vtype	*vtype;
	_jc_soot_coffi_Instruction__5flongbranch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5flongbranch$vtype _jc_soot_coffi_Instruction__5flongbranch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5flongbranch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5flongbranch$class_object;

#endif	/* _JC_soot_coffi_Instruction__5flongbranch_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5flongbranch.h <==
// class soot.coffi.Instruction_longbranch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 5e7f431907ff88dc soot_coffi_Instruction__5flongbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbranch

#include "soot/coffi/Instruction__5fbranch.h"

#ifndef _JC_soot_coffi_Instruction__5flongbranch_H_
#define _JC_soot_coffi_Instruction__5flongbranch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5flongbranch$sub_refs	_jc_soot_coffi_Instruction__5flongbranch$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs	_jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$refs	_jc_soot_coffi_Instruction__5flongbranch$refs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$nonrefs	_jc_soot_coffi_Instruction__5flongbranch$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5flongbranch$object	_jc_soot_coffi_Instruction__5flongbranch$object;

typedef const struct _jc_soot_coffi_Instruction__5flongbranch$vmethods	_jc_soot_coffi_Instruction__5flongbranch$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5flongbranch$vtable	_jc_soot_coffi_Instruction__5flongbranch$vtable;
typedef const struct _jc_soot_coffi_Instruction__5flongbranch$vtype	_jc_soot_coffi_Instruction__5flongbranch$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5flongbranch$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5flongbranch$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5flongbranch$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5flongbranch$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5flongbranch$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5flongbranch$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5flongbranch$method_info$parse$107dd9a35b0eb485;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5flongbranch$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5flongbranch$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5flongbranch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5flongbranch$vmethods	soot_coffi_Instruction__5flongbranch;
};

// Vtype
struct _jc_soot_coffi_Instruction__5flongbranch$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5flongbranch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5flongbranch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5flongbranch$refs {
    _jc_soot_coffi_Instruction__5flongbranch$sub_refs	soot_coffi_Instruction__5flongbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5flongbranch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5flongbranch$sub_nonrefs	soot_coffi_Instruction__5flongbranch;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5flongbranch$object {
	_jc_soot_coffi_Instruction__5flongbranch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5flongbranch$vtype	*vtype;
	_jc_soot_coffi_Instruction__5flongbranch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5flongbranch$vtype _jc_soot_coffi_Instruction__5flongbranch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5flongbranch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5flongbranch$class_object;

#endif	/* _JC_soot_coffi_Instruction__5flongbranch_H_ */
